@@ -4,7 +4,7 @@ from docopt import docopt
 from localstack import config
 from localstack.utils.common import truncate, format_bytes
 from localstack_ext import constants as ext_constants
-from localstack_ext.bootstrap import licensing
+from localstack_ext.bootstrap import auth
 
 
 def cmd_login(argv, args):
@@ -17,16 +17,25 @@ Options:
   --username=<>           OAuth username for login
     """
     args.update(docopt(cmd_login.__doc__.strip(), argv=argv))
-    auth = import_auth()
 
     try:
         provider = args['--provider'] or 'internal'
         auth.login(provider, args['--username'])
-        print('Successfully logged in')
+        print('Successfully logged in.')
     except Exception as e:
         raise Exception('Authentication error: %s' % e)
 
 
+def cmd_logout(argv, args):
+    """
+Usage:
+  localstack logout
+    """
+    args.update(docopt(cmd_logout.__doc__.strip(), argv=argv))
+    auth.logout()
+    print('Successfully logged out.')
+
+
 def cmd_ci(argv, args):
     """
 Usage:
@@ -42,7 +51,6 @@ Options:
   --token=<>            API access token for CI provider
     """
     args.update(docopt(cmd_ci.__doc__.strip(), argv=argv))
-    auth = import_auth()
 
     if args['<subcommand>'] == 'repos':
         provider = args['--provider'] or 'travis'
@@ -55,17 +63,6 @@ Options:
         print(repo, token)
 
 
-def cmd_logout(argv, args):
-    """
-Usage:
-  localstack logout
-    """
-    args.update(docopt(cmd_logout.__doc__.strip(), argv=argv))
-    auth = import_auth()
-
-    auth.logout()
-
-
 def cmd_config(argv, args):
     """
 Usage:
@@ -77,7 +74,6 @@ Arguments:
   <value>           Value of configuration property to write
     """
     args.update(docopt(cmd_config.__doc__.strip(), argv=argv))
-    auth = import_auth()
 
     if args['<value>']:
         auth.set_user_config(args['<key>'], args['<value>'])
@@ -192,15 +188,6 @@ def register_commands():
 # HELPER FUNCTIONS
 # -----------------
 
-def import_auth():
-    try:
-        with licensing.prepare_environment():
-            from localstack_ext.utils import auth
-            return auth
-    except Exception:
-        raise Exception('Command not available in this version')
-
-
 def mand_params(args, names=[]):
     return get_params(args, names, mandatory=True)
 
