@@ -1,12 +1,12 @@
 import os
-ahUwD=Exception
-ahUwb=False
-ahUwR=str
-ahUwW=int
-ahUwO=range
-ahUwr=len
-ahUwY=object
-ahUwm=True
+Brszp=Exception
+Brszg=False
+Brszm=str
+Brszq=int
+BrszJ=range
+BrszK=len
+BrszL=object
+Brszu=True
 import re
 import sys
 import glob
@@ -27,7 +27,7 @@ def read_api_key():
  key=os.environ.get('LOCALSTACK_API_KEY')
  if key:
   return key
- raise ahUwD('Unable to retrieve API key. Please configure $LOCALSTACK_API_KEY in your environment')
+ raise Brszp('Unable to retrieve API key. Please configure $LOCALSTACK_API_KEY in your environment')
 def fetch_key():
  api_key=read_api_key()
  if api_key=='test':
@@ -35,10 +35,10 @@ def fetch_key():
  data={'api_key':api_key,'version':VERSION}
  try:
   logging.getLogger('py.warnings').setLevel(logging.ERROR)
-  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=ahUwb)
+  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=Brszg)
   key_base64=json.loads(result.content)['key']
   cache_key_locally(api_key,key_base64)
- except ahUwD:
+ except Brszp:
   key_base64=load_cached_key(api_key)
  finally:
   logging.getLogger('py.warnings').setLevel(logging.WARNING)
@@ -46,25 +46,25 @@ def fetch_key():
  return decoded_key
 def cache_key_locally(api_key,key_b64):
  configs=localstack_config.load_config_file()
- timestamp=ahUwR(ahUwW(now_utc()))
+ timestamp=Brszm(Brszq(now_utc()))
  key_raw=to_str(base64.b64decode(key_b64))
- for i in ahUwO(ahUwr(timestamp)):
+ for i in BrszJ(BrszK(timestamp)):
   key_raw=str_insert(key_raw,i*2,timestamp[i])
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
- configs['cached_key']={'timestamp':ahUwW(timestamp),'key_hash':md5(api_key),'key':key_b64}
+ configs['cached_key']={'timestamp':Brszq(timestamp),'key_hash':md5(api_key),'key':key_b64}
  save_file(localstack_config.CONFIG_FILE_PATH,json.dumps(configs))
  return configs
 def load_cached_key(api_key):
  configs=localstack_config.load_config_file()
  cached_key=configs['cached_key']
  if cached_key.get('key_hash')!=md5(api_key):
-  raise ahUwD('Cached key was created for a different API key')
+  raise Brszp('Cached key was created for a different API key')
  now=now_utc()
  if(now-cached_key['timestamp'])>MAX_KEY_CACHE_DURATION_SECS:
-  raise ahUwD('Cached key expired')
- timestamp=ahUwR(cached_key['timestamp'])
+  raise Brszp('Cached key expired')
+ timestamp=Brszm(cached_key['timestamp'])
  key_raw=to_str(base64.b64decode(cached_key['key']))
- for i in ahUwO(ahUwr(timestamp)):
+ for i in BrszJ(BrszK(timestamp)):
   assert key_raw[i]==timestamp[i]
   key_raw=str_remove(key_raw,i)
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
@@ -103,22 +103,22 @@ def cleanup_environment():
       if os.path.exists(delete_file):
        os.remove(delete_file)
 def prepare_environment():
- class OnClose(ahUwY):
+ class OnClose(BrszL):
   def __exit__(self,*args,**kwargs):
    if not ENV_PREPARED.get('finalized'):
     cleanup_environment()
-   ENV_PREPARED['finalized']=ahUwm
+   ENV_PREPARED['finalized']=Brszu
   def __enter__(self,*args,**kwargs):
    pass
  if not ENV_PREPARED.get('finalized'):
   try:
    key=fetch_key()
    if not key:
-    raise ahUwD('Unable to fetch and validate API key from environment')
+    raise Brszp('Unable to fetch and validate API key from environment')
    if key!='test':
     decrypt_files(key)
     LOG.info('Successfully activated API key')
-  except ahUwD as e:
+  except Brszp as e:
    if os.environ.get('LOCALSTACK_API_KEY')and localstack_config.is_env_true('LOG_LICENSE_ISSUES'):
     LOG.warning('Unable to activate API key: %s %s'%(e,traceback.format_exc()))
    if config.REQUIRE_PRO:
@@ -129,7 +129,7 @@ def get_auth_headers():
  configs=localstack_config.load_config_file()
  login_info=configs.get('login')
  if not login_info:
-  raise ahUwD('Please log in first')
+  raise Brszp('Please log in first')
  auth_token=login_info['token']
  if not auth_token.startswith('%s '%login_info['provider']):
   auth_token='%s %s'%(login_info['provider'],auth_token)
