@@ -1,16 +1,16 @@
 import os
-TJFbq=object
-TJFbh=None
-TJFbs=Exception
-TJFba=set
-TJFbN=property
-TJFbV=classmethod
-TJFbG=True
-TJFbX=getattr
-TJFbe=type
-TJFbD=isinstance
-TJFbv=list
-TJFbg=False
+ocMey=object
+ocMek=None
+ocMev=Exception
+ocMew=set
+ocMeB=property
+ocMeF=classmethod
+ocMeu=True
+ocMeP=getattr
+ocMez=type
+ocMeI=isinstance
+ocMep=list
+ocMeL=False
 import re
 import json
 import logging
@@ -25,17 +25,17 @@ from localstack.utils.common import(load_file,to_str,to_bytes,mkdir,save_file,cp
 from localstack_ext.bootstrap.licensing import get_auth_headers
 LOG=logging.getLogger(__name__)
 PERISTED_FOLDERS=['api_states','dynamodb','kinesis']
-class CloudPodManager(TJFbq):
+class CloudPodManager(ocMey):
  BACKEND='_none_'
- def __init__(self,pod_name=TJFbh,config=TJFbh):
+ def __init__(self,pod_name=ocMek,config=ocMek):
   self.pod_name=pod_name
   self._pod_config=config
  def push(self):
-  raise TJFbs('Not implemented')
+  raise ocMev('Not implemented')
  def pull(self):
-  raise TJFbs('Not implemented')
+  raise ocMev('Not implemented')
  def get_pod_size(self):
-  raise TJFbs('Not implemented')
+  raise ocMev('Not implemented')
  def restart_container(self):
   LOG.info('Restarting LocalStack instance with updated persistence state - this may take some time ...')
   data={'action':'restart'}
@@ -49,20 +49,20 @@ class CloudPodManager(TJFbq):
    response=requests.get(url)
    content=json.loads(to_str(response.content))
    statuses=[v for k,v in content['services'].items()]
-   assert TJFba(statuses)==TJFba(['running'])
+   assert ocMew(statuses)==ocMew(['running'])
   retry(check_status,sleep=3,retries=10)
- @TJFbN
+ @ocMeB
  def pod_config(self):
   return self._pod_config or PodConfigManager.pod_config(self.pod_name)
- @TJFbV
+ @ocMeF
  def get(cls,pod_name):
   pod_config=PodConfigManager.pod_config(pod_name)
   backend=pod_config.get('backend')
   for clazz in cls.__subclasses__():
    if clazz.BACKEND==backend:
     return clazz(pod_name=pod_name,config=pod_config)
-  raise TJFbs('Unable to find Cloud Pod manager implementation type "%s"'%backend)
- @TJFbV
+  raise ocMev('Unable to find Cloud Pod manager implementation type "%s"'%backend)
+ @ocMeF
  def data_dir(cls):
   if not config.DATA_DIR:
    try:
@@ -74,10 +74,10 @@ class CloudPodManager(TJFbq):
     data_dir_host=[m for m in mounts if m['Destination']==data_dir_env][0]['Source']
     data_dir_host=re.sub(r'^(/host_mnt)?',r'',data_dir_host)
     config.DATA_DIR=data_dir_host
-   except TJFbs:
+   except ocMev:
     LOG.warning('''Unable to determine DATA_DIR from LocalStack Docker container - please make sure $MAIN_CONTAINER_NAME is configured properly''')
   if not config.DATA_DIR:
-   raise TJFbs('Working with local cloud pods requires $DATA_DIR configuration')
+   raise ocMev('Working with local cloud pods requires $DATA_DIR configuration')
   return config.DATA_DIR
 class CloudPodManagerGit(CloudPodManager):
  BACKEND='git'
@@ -88,9 +88,9 @@ class CloudPodManagerGit(CloudPodManager):
   remote_location=self.pod_config.get('url')
   try:
    porcelain.pull(repo,remote_location,refspecs=branch)
-  except TJFbs as e:
+  except ocMev as e:
    LOG.info('Unable to pull repo: %s'%e)
-  is_empty_repo=b'HEAD' not in repo or repo.refs.allkeys()==TJFba([b'HEAD'])
+  is_empty_repo=b'HEAD' not in repo or repo.refs.allkeys()==ocMew([b'HEAD'])
   if is_empty_repo:
    LOG.debug('Initializing empty repository %s'%self.clone_dir)
    init_file=os.path.join(self.clone_dir,'.init')
@@ -98,7 +98,7 @@ class CloudPodManagerGit(CloudPodManager):
    porcelain.add(repo,init_file)
    porcelain.commit(repo,message='Initial commit')
   if branch not in repo:
-   porcelain.branch_create(repo,branch,force=TJFbG)
+   porcelain.branch_create(repo,branch,force=ocMeu)
   self.switch_branch(branch)
   for folder in PERISTED_FOLDERS:
    LOG.info('Copying persistence folder %s to local git repo %s'%(folder,self.clone_dir))
@@ -119,7 +119,7 @@ class CloudPodManagerGit(CloudPodManager):
   branch=self.pod_config.get('branch')
   remote_ref=b'refs/heads/%s'%to_bytes(branch)
   if remote_ref not in remote_refs:
-   raise TJFbs('Unable to find branch "%s" in remote git repo'%branch)
+   raise ocMev('Unable to find branch "%s" in remote git repo'%branch)
   remote_location=self.pod_config.get('url')
   self.switch_branch(branch)
   branch_ref=b'refs/heads/%s'%to_bytes(branch)
@@ -131,13 +131,13 @@ class CloudPodManagerGit(CloudPodManager):
   for folder in PERISTED_FOLDERS:
    src_folder=os.path.join(self.clone_dir,folder)
    tgt_folder=os.path.join(self.data_dir(),folder)
-   cp_r(src_folder,tgt_folder,rm_dest_on_conflict=TJFbG)
+   cp_r(src_folder,tgt_folder,rm_dest_on_conflict=ocMeu)
   self.restart_container()
  def client(self):
   client,path=get_transport_and_path_from_url(self.pod_config.get('url'))
   return client,path
  def local_repo(self):
-  self.clone_dir=TJFbX(self,'clone_dir',TJFbh)
+  self.clone_dir=ocMeP(self,'clone_dir',ocMek)
   if not self.clone_dir:
    pod_dir_name=re.sub(r'(\s|/)+','',self.pod_name)
    self.clone_dir=os.path.join(config.TMP_FOLDER,'pods',pod_dir_name,'repo')
@@ -157,58 +157,58 @@ class CloudPodManagerGit(CloudPodManager):
  def get_pod_size(self):
   self.local_repo()
   return disk_usage(self.clone_dir)
-class PodConfigManagerMeta(TJFbe):
+class PodConfigManagerMeta(ocMez):
  def __getattr__(cls,attr):
   def _call(*args,**kwargs):
-   result=TJFbh
+   result=ocMek
    for manager in cls.CHAIN:
     try:
-     tmp=TJFbX(manager,attr)(*args,**kwargs)
+     tmp=ocMeP(manager,attr)(*args,**kwargs)
      if tmp:
       if not result:
        result=tmp
-      elif TJFbD(tmp,TJFbv)and TJFbD(result,TJFbv):
+      elif ocMeI(tmp,ocMep)and ocMeI(result,ocMep):
        result.extend(tmp)
-    except TJFbs:
+    except ocMev:
      pass
-   if result is not TJFbh:
+   if result is not ocMek:
     return result
-   raise TJFbs('Unable to run operation "%s" for local or remote configuration'%attr)
+   raise ocMev('Unable to run operation "%s" for local or remote configuration'%attr)
   return _call
-class PodConfigManager(TJFbq,metaclass=PodConfigManagerMeta):
+class PodConfigManager(ocMey,metaclass=PodConfigManagerMeta):
  CHAIN=[]
- @TJFbV
+ @ocMeF
  def pod_config(cls,pod_name):
   pods=PodConfigManager.list_pods()
   pod_config=[pod for pod in pods if pod['pod_name']==pod_name]
   if not pod_config:
-   raise TJFbs('Unable to find config for pod named "%s"'%pod_name)
+   raise ocMev('Unable to find config for pod named "%s"'%pod_name)
   return pod_config[0]
-class PodConfigManagerLocal(TJFbq):
+class PodConfigManagerLocal(ocMey):
  CONFIG_FILE='.localstack.yml'
  def list_pods(self):
-  local_pods=self._load_config(safe=TJFbG).get('pods',{})
+  local_pods=self._load_config(safe=ocMeu).get('pods',{})
   local_pods=[{'pod_name':k,'state':'Local Only',**v}for k,v in local_pods.items()]
-  existing_names=TJFba([pod['pod_name']for pod in local_pods])
+  existing_names=ocMew([pod['pod_name']for pod in local_pods])
   result=[pod for pod in local_pods if pod['pod_name']not in existing_names]
   return result
  def store_pod_metadata(self,pod_name,metadata):
   pass
- def _load_config(self,safe=TJFbg):
+ def _load_config(self,safe=ocMeL):
   try:
    return yaml.load(to_str(load_file(self.CONFIG_FILE)))
-  except TJFbs:
+  except ocMev:
    if safe:
     return{}
-   raise TJFbs('Unable to find and parse config file "%s"'%self.CONFIG_FILE)
-class PodConfigManagerRemote(TJFbq):
+   raise ocMev('Unable to find and parse config file "%s"'%self.CONFIG_FILE)
+class PodConfigManagerRemote(ocMey):
  def list_pods(self):
   result=[]
   auth_headers=get_auth_headers()
   response=safe_requests.get('%s/cloudpods'%API_ENDPOINT,headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise TJFbs('Unable to fetch list of pods from API (code %s): %s'%(response.status_code,content))
+   raise ocMev('Unable to fetch list of pods from API (code %s): %s'%(response.status_code,content))
   remote_pods=json.loads(to_str(content)).get('cloudpods',[])
   remote_pods=[{'state':'Shared',**pod}for pod in remote_pods]
   result.extend(remote_pods)
@@ -219,7 +219,7 @@ class PodConfigManagerRemote(TJFbq):
   response=safe_requests.post('%s/cloudpods'%API_ENDPOINT,json.dumps(metadata),headers=auth_headers)
   content=response.content
   if response.status_code>=400:
-   raise TJFbs('Unable to store pod metadata in API (code %s): %s'%(response.status_code,content))
+   raise ocMev('Unable to store pod metadata in API (code %s): %s'%(response.status_code,content))
   return json.loads(to_str(content))
 PodConfigManager.CHAIN.append(PodConfigManagerLocal())
 PodConfigManager.CHAIN.append(PodConfigManagerRemote())
@@ -231,7 +231,7 @@ def push_state(pod_name,args):
  backend.push()
 def pull_state(pod_name,args):
  if not pod_name:
-  raise TJFbs('Need to specify a pod name')
+  raise ocMev('Need to specify a pod name')
  backend=CloudPodManager.get(pod_name=pod_name)
  backend.pull()
 def list_pods(args):
